@@ -174,6 +174,15 @@ def expected_input_yaml_dict():
                 "type": "local",
             },
         },
+        'REPLACE_SCHEMA_WITH_DYN_VARS': {
+            'LOCAL': {
+                'local': {
+                    'file_path': f'{constants.TEST_RESOURCES}/data/input/{{file_name_to_replace}}.parquet',
+                    'file_type': 'parquet'},
+                'type': 'local'},
+            'schema': {
+                'file_path': f'{constants.TEST_RESOURCES}/schemas/bar.yaml'}
+        },
         "TEMPLATED_FILE_PATH": {
             "CLOUD": {
                 "s3": {
@@ -206,6 +215,7 @@ def expected_input_sources():
         "READ_FROM_KAFKA",
         "TEMPLATED_FILE_PATH",
         "READ_FROM_PARQUET_TEMPLATED",
+        "REPLACE_SCHEMA_WITH_DYN_VARS"
     ]
 
 
@@ -234,7 +244,7 @@ def expected_s3_csv_local_mapping():
                 "is_lower_than": {"apply": True, "options": {"threshold": 2000}},
             },
             "foo_name": {
-                "has_acceptable_categorical_values": {
+                "is_in": {
                     "apply": True,
                     "options": {"categorical_values": ["class_a", "class_b", "class_c"]},
                 },
@@ -267,7 +277,7 @@ def expected_s3_csv_cloud_mapping():
                 "is_lower_than": {"apply": True, "options": {"threshold": 2000}},
             },
             "foo_name": {
-                "has_acceptable_categorical_values": {
+                "is_in": {
                     "apply": True,
                     "options": {"categorical_values": ["class_a", "class_b", "class_c"]},
                 },
@@ -425,7 +435,7 @@ def input_schema_definition():
                 "metrics": None,
                 "type": "object",
                 "validations": {
-                    "has_acceptable_categorical_values": {
+                    "is_in": {
                         "apply": True,
                         "options": {"categorical_values": ["class_a", "class_b", "class_c"]},
                     },
@@ -467,7 +477,7 @@ def expected_schema_definition():
                 "metrics": ["CountsPerLabel"],
                 "type": "object",
                 "validations": {
-                    "has_acceptable_categorical_values": {
+                    "is_in": {
                         "apply": True,
                         "options": {"categorical_values": ["class_a", "class_b", "class_c"]},
                     },
@@ -492,7 +502,7 @@ def expected_validations():
             "is_lower_than": {"apply": True, "options": {"threshold": 2000}},
         },
         "foo_name": {
-            "has_acceptable_categorical_values": {
+            "is_in": {
                 "apply": True,
                 "options": {"categorical_values": ["class_a", "class_b", "class_c"]},
             },
@@ -536,7 +546,7 @@ def invalid_dataframe():
 def expected_messages():
     return {
         "has_unique_values",
-        "has_acceptable_categorical_values",
+        "is_in",
         "is_greater_than",
         "is_lower_than",
     }
